@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.0.3 $
+### $Release: 0.0.4 $
 ### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
@@ -25,10 +25,10 @@ class MainObject(object):
         self.command = os.path.basename(argv[0])
         self.args = argv[1:]
 
-    def invoke():
+    def invoke(self):
         raise NotImplementedError("%s#invoke(): not implemented yet." % self.__class__.__name__)
 
-    def main():
+    def main(self):
         raise NotImplementedError("%s#main(): not implemented yet." % self.__class__.__name__)
 
     def _load_property_file(self, filename=None):
@@ -64,10 +64,11 @@ class MainCommand(MainObject):
         "-D[N]:   debug level (default: 1)",
         "-q:      quiet",
         "-f file: kookbook",
-        "-F:      forcedly",
+        "-F:      run forcedly (ignore timestamps)",
         "-n:      not execute (dry run)",
         "-l:      list public recipes",
         "-L:      list all recipes",
+        "-R:      search parent directory recursively for Kookbook",
         "--name=value: property name and value",
         "--name:       property name and value(=True)",
     )
@@ -93,18 +94,30 @@ class MainCommand(MainObject):
             if v is None:
                 raise CommandOptionError('-D%s: integer is required.' % opts['D'])
             config.debug_level = v
-        if opts.get('f'):
-            arg = opts['f']
-            if not os.path.exists(arg): raise CommandOptionError("-f %s: not found." % arg)
-            if not os.path.isfile(arg): raise CommandOptionError("-f %s: not a file." % arg)
+        ## find cookbook
+        bookname = opts.get('f', config.cookbook_filename)
+        bookpath = bookname
+        if opts.get('R'):
+            abspath = os.path.abspath
+            while not os.path.exists(bookpath):
+                tmp = os.path.join("..", bookpath)
+                if abspath(tmp) == abspath(bookpath): break
+                bookpath = tmp
+        if not os.path.exists(bookpath):
+            msg = opts.get('f', None) and '-f %s: not found.' or '%s: not found.'
+            raise CommandOptionError(msg % bookname)
+        if not os.path.isfile(bookpath):
+            msg = opts.get('f', None) and '-f %s: not a file.' or '%s: not a file.'
+            raise CommandOptionError(msg % bookname)
+        ## change directory if $PYKOOK_COLIMB is set
+        if bookname != bookpath:
+            path = bookpath[:-len(bookname)]
+            os.chdir(path)
         ## property file
         props = self._load_property_file()
         if longopts:
             props.update(longopts)
         ## create cookbook
-        bookname = opts.get('f', config.cookbook_filename)
-        if not os.path.isfile(bookname):
-            raise CommandOptionError("%s: not found." % bookname)
         cookbook = Cookbook.new(bookname, props)
         ## list recipes
         if opts.get('l') or opts.get('L'):
