@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.0.3 $
+### $Release: 0.0.4 $
 ### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
@@ -220,7 +220,7 @@ class CommandOptionParser(object):
                 elif arg2:  spices[name] = arg2 == 'N' and 1 or True
                 else:       spices[name] = False
                 continue
-            raise ArgumentError("%s: invalid command optin definition." % optdef_str)
+            raise ArgumentError("%s: invalid command option definition." % optdef_str)
         self.spices = spices
         self.helps = helps
         return spices, help
