@@ -1,12 +1,12 @@
 ###
-### $Release: 0.0.3 $
+### $Release: 0.0.4 $
 ### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
 import oktest
 from oktest import *
-import sys, os, re
+import sys, os, re, shutil, random
 from glob import glob
 try:
     from StringIO import StringIO      # 2.x
@@ -76,21 +76,19 @@ char *command = "hello";
 
 class KookMainCommandTest(object):
 
-
     def before_each(self):
+        self._currdir = os.getcwd()
+        self._tmpdir  = str(random.random())
+        os.mkdir(self._tmpdir)
+        os.chdir(self._tmpdir)
         #_setup_stdio()
         write_file('hello.c', HELLO_C)
         write_file('hello.h', HELLO_H)
 
     def after_each(self):
-        for x in glob('Kookbook*.py'):
-            os.unlink(x)
-        for x in glob('hello*'):
-            os.unlink(x)
         #_teardown_stdio()
-        if hasattr(self, 'byprods'):
-            for x in self.byprods:
-                os.unlink(x)
+        os.chdir(self._currdir)
+        shutil.rmtree(self._tmpdir)
 
 
     def test_init(self):
@@ -127,10 +125,11 @@ pykook - build tool like Make, Rake, Ant, or Cook
   -D[N]               : debug level (default: 1)
   -q                  : quiet
   -f file             : kookbook
-  -F                  : forcedly
+  -F                  : run forcedly (ignore timestamps)
   -n                  : not execute (dry run)
   -l                  : list public recipes
   -L                  : list all recipes
+  -R                  : search parent directory recursively for Kookbook
   --name=value        : property name and value
   --name              : property name and value(=True)
 """[1:]
@@ -295,7 +294,6 @@ def file_html(c):
         _write(input)
         write_file("index.html", "xxx")
         write_file("index.txt", "foobar")
-        self.byprods = ('index.txt', 'index.html', )
         ## recipe should not be invoked because product is newer
         soutput, eoutput, status = _main_command("pykook index.html")
         ok(soutput, '==', "")
@@ -330,7 +328,6 @@ def file_html(c):
 """[1:]
         _write(input)
         write_file("index.txt", "xxx")
-        self.byprods = ['index.txt']
         ## products should not be created!
         try:
             soutput, eoutput, status = _main_command("pykook -n index.xhtml")
@@ -442,7 +439,6 @@ CC = 'tcc'
 """[1:]
         filename = "Properties.py"
         write_file(filename, input)
-        self.byprods = [filename]
         ## Properties.py overrides property value
         expected = r"""
 ### * echo (recipe=task_echo)
@@ -525,6 +521,39 @@ File recipes:
         ok(soutput, '==', expected)
         ok(eoutput, '==', "")
 
+    def ktest_search_recursively(self):
+        curr_dir = os.getcwd()
+        tmp_root = str(random.random())
+        tmp_dir  = os.path.join(tmp_root, "foo", "bar")
+        book_content = r"""
+@recipe
+def cwd(c):
+    import os
+    echo("cwd=" + os.getcwd())
+"""
+        try:
+            os.makedirs(tmp_dir)
+            bookpath = os.path.join(tmp_root, "Kookbook.py")
+            write_file(bookpath, book_content)
+            os.chdir(tmp_dir)
+            #
+            soutput, eoutput, status = _main_command("pykook cwd")
+            ok(soutput, '==', "")
+            ok(eoutput, '==', "pykook: Kookbook.py: not found.\n")
+            #
+            expected = r'''
+### * cwd (recipe=cwd)
+$ echo cwd=/Users/kwatch/src/kook2/python/%s
+cwd=/Users/kwatch/src/kook2/python/%s
+'''[1:] % (tmp_root, tmp_root)
+            soutput, eoutput, status = _main_command("pykook -R cwd")
+            ok(soutput, '==', expected)
+            ok(eoutput, '==', "")
+            #
+        finally:
+            os.chdir(curr_dir)
+            shutil.rmtree(tmp_root)
+
 
 SCRIPT = r"""
 kook_desc = "helper script"
